@@ -28,6 +28,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "etats_affiche.h"
@@ -45,6 +46,7 @@
 #include "utils_dates.h"
 #include "navigation.h"
 #include "gsb_real.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "structures.h"
 #include "etats_config.h"
@@ -52,19 +54,22 @@
 
 /*START_STATIC*/
 static void etat_affiche_attach_hsep ( int x, int x2, int y, int y2);
-static void etat_affiche_attach_label ( gchar * text, gint properties, int x, int x2, int y, int y2, 
+static void etat_affiche_attach_label ( gchar * text, gint properties, int x, int x2, int y, int y2,
 				 enum alignement align, gint transaction_number );
 static void etat_affiche_attach_vsep ( int x, int x2, int y, int y2);
 /*END_STATIC*/
 
 
 
-
+/* WTF??? See etats_calculs.c too... */
 static gint ancien_tiers_etat;
+extern gint ancien_tiers_etat;
+
+
+static gint titres_affiches;
 
 /*START_EXTERN*/
 extern gint ancien_compte_etat;
-extern gint ancien_tiers_etat;
 extern gint ancienne_categ_etat;
 extern gint ancienne_categ_speciale_etat;
 extern gint ancienne_ib_etat;
@@ -106,8 +111,6 @@ extern const gchar *nom_ib_en_cours;
 extern const gchar *nom_ss_categ_en_cours;
 extern const gchar *nom_ss_ib_en_cours;
 extern const gchar *nom_tiers_en_cours;
-extern gsb_real null_real;
-extern gint titres_affiches;
 /*END_EXTERN*/
 
 
@@ -204,7 +207,7 @@ gint etat_affiche_affiche_total_categories ( gint ligne )
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
             g_free ( text );
 
-	    text = gsb_real_get_string_with_currency (montant_categ_etat, devise_categ_etat, TRUE );
+	    text = utils_real_get_string_with_currency (montant_categ_etat, devise_categ_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes,
 					ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
@@ -220,19 +223,19 @@ gint etat_affiche_affiche_total_categories ( gint ligne )
 
 	    if ( gsb_data_report_get_show_report_transaction_amount (current_report_number))
 	    {
-	        gchar* fmtstr; 
+	        gchar* fmtstr;
 		if ( nb_ope_categ_etat <= 1 )
 		    fmtstr = _("%s (%d transaction)");
 		else
 		    fmtstr = _("%s (%d transactions)");
 
-		tmpstr = gsb_real_get_string_with_currency ( montant_categ_etat,
+		tmpstr = utils_real_get_string_with_currency ( montant_categ_etat,
 										 devise_categ_etat, TRUE  );
 	        text = g_strdup_printf ( fmtstr , tmpstr, nb_ope_categ_etat );
 		g_free ( tmpstr );
 	    }
 	    else
-		text = gsb_real_get_string_with_currency ( montant_categ_etat,
+		text = utils_real_get_string_with_currency ( montant_categ_etat,
 							   devise_categ_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes,
@@ -326,7 +329,7 @@ gint etat_affiche_affiche_total_sous_categ ( gint ligne )
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
-	    text = gsb_real_get_string_with_currency (montant_sous_categ_etat, devise_categ_etat, TRUE);
+	    text = utils_real_get_string_with_currency (montant_sous_categ_etat, devise_categ_etat, TRUE);
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
@@ -342,16 +345,16 @@ gint etat_affiche_affiche_total_sous_categ ( gint ligne )
 	    {
 	        gchar* fmtstr;
 		if ( nb_ope_sous_categ_etat <= 1 )
-		    fmtstr = _("%s (%d transaction)"); 
+		    fmtstr = _("%s (%d transaction)");
 		else
 		    fmtstr = _("%s (%d transactions)");
-		tmpstr = gsb_real_get_string_with_currency ( montant_sous_categ_etat, devise_categ_etat, TRUE  );
-	        text = g_strdup_printf ( fmtstr, tmpstr, 
+		tmpstr = utils_real_get_string_with_currency ( montant_sous_categ_etat, devise_categ_etat, TRUE  );
+	        text = g_strdup_printf ( fmtstr, tmpstr,
 				nb_ope_sous_categ_etat );
 	        g_free ( tmpstr );
 	    }
 	    else
-		text = gsb_real_get_string_with_currency ( montant_sous_categ_etat,
+		text = utils_real_get_string_with_currency ( montant_sous_categ_etat,
 							   devise_categ_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
@@ -411,7 +414,7 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	    {
 		if ( gsb_data_report_get_show_report_transaction_amount (current_report_number))
 		{
-		    gchar* fmtstr; 
+		    gchar* fmtstr;
 		    if ( nb_ope_ib_etat <= 1 )
 			fmtstr = _("Total %s (%d transaction)");
 		    else
@@ -425,7 +428,7 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	    {
 		if ( gsb_data_report_get_show_report_transaction_amount (current_report_number))
 		{
-		    gchar* fmtstr; 
+		    gchar* fmtstr;
 		    if ( nb_ope_ib_etat <= 1 )
 			fmtstr = _("Budgetary lines total: (%d transaction): ");
 		    else
@@ -439,7 +442,7 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
-	    text = gsb_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
+	    text = utils_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
@@ -455,15 +458,15 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	    {
 	        gchar* fmtstr;
 		if ( nb_ope_ib_etat <= 1 )
-		    fmtstr = _("%s (%d transaction)"); 
+		    fmtstr = _("%s (%d transaction)");
 		else
-		    fmtstr = _("%s (%d transactions)"); 
-		tmpstr2 = gsb_real_get_string_with_currency (montant_ib_etat, devise_ib_etat, TRUE  );
+		    fmtstr = _("%s (%d transactions)");
+		tmpstr2 = utils_real_get_string_with_currency (montant_ib_etat, devise_ib_etat, TRUE  );
 		text = g_strdup_printf ( fmtstr, tmpstr2 , nb_ope_ib_etat );
 		g_free (tmpstr2);
 	    }
 	    else
-		text = gsb_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
+		text = utils_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
@@ -524,7 +527,7 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 	    {
 		if ( gsb_data_report_get_show_report_transaction_amount (current_report_number))
 		{
-		    gchar* fmtstr; 
+		    gchar* fmtstr;
 		    if ( nb_ope_sous_ib_etat <= 1 )
 			fmtstr = _("Total %s: %s (%d transaction): ");
 		    else
@@ -553,7 +556,7 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
-	    text = gsb_real_get_string_with_currency (montant_sous_ib_etat, devise_ib_etat, TRUE );
+	    text = utils_real_get_string_with_currency (montant_sous_ib_etat, devise_ib_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
@@ -571,17 +574,17 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 	        gchar* tmpstr;
 
 		if ( nb_ope_sous_ib_etat <= 1 )
-		    fmtstr = _("%s (%d transaction)"); 
+		    fmtstr = _("%s (%d transaction)");
 		else
-		    fmtstr = _("%s (%d transactions)"); 
-		tmpstr = gsb_real_get_string_with_currency (montant_sous_ib_etat, 
+		    fmtstr = _("%s (%d transactions)");
+		tmpstr = utils_real_get_string_with_currency (montant_sous_ib_etat,
 							    devise_ib_etat, TRUE  );
-		text = g_strdup_printf ( fmtstr, tmpstr, 
+		text = g_strdup_printf ( fmtstr, tmpstr,
 					 nb_ope_sous_ib_etat );
 		g_free ( tmpstr );
 	    }
 	    else
-		text = gsb_real_get_string_with_currency ( montant_sous_ib_etat, devise_ib_etat, TRUE );
+		text = utils_real_get_string_with_currency ( montant_sous_ib_etat, devise_ib_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
@@ -664,7 +667,7 @@ gint etat_affiche_affiche_total_compte ( gint ligne )
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
-	    text = gsb_real_get_string_with_currency (montant_compte_etat, devise_compte_en_cours_etat, TRUE );
+	    text = utils_real_get_string_with_currency (montant_compte_etat, devise_compte_en_cours_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
@@ -680,19 +683,19 @@ gint etat_affiche_affiche_total_compte ( gint ligne )
 	    {
 	        gchar* fmtstr;
 		if ( nb_ope_compte_etat <= 1 )
-		    fmtstr = _("%s (%d transaction)"); 
+		    fmtstr = _("%s (%d transaction)");
 		else
-		    fmtstr = _("%s (%d transactions)"); 
-		tmpstr = gsb_real_get_string_with_currency ( montant_compte_etat,
+		    fmtstr = _("%s (%d transactions)");
+		tmpstr = utils_real_get_string_with_currency ( montant_compte_etat,
 				devise_compte_en_cours_etat, TRUE  );
-		text = g_strdup_printf ( fmtstr, tmpstr, 
+		text = g_strdup_printf ( fmtstr, tmpstr,
 					     nb_ope_compte_etat );
 	        g_free ( tmpstr );
 	    }
 	    else
-		text = gsb_real_get_string_with_currency ( montant_compte_etat, devise_compte_en_cours_etat, TRUE );
+		text = utils_real_get_string_with_currency ( montant_compte_etat, devise_compte_en_cours_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );  
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 	}
@@ -772,7 +775,7 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
-	    text = gsb_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
+	    text = utils_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
@@ -788,16 +791,16 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 	    {
 	        gchar* fmtstr;
 		if ( nb_ope_tiers_etat <= 1 )
-		    fmtstr = _("%s (%d transaction)"); 
+		    fmtstr = _("%s (%d transaction)");
 		else
-		    fmtstr = _("%s (%d transactions)"); 
-		tmpstr = gsb_real_get_string_with_currency (montant_tiers_etat,
+		    fmtstr = _("%s (%d transactions)");
+		tmpstr = utils_real_get_string_with_currency (montant_tiers_etat,
 										devise_tiers_etat, TRUE  );
 		text = g_strdup_printf ( fmtstr, tmpstr, nb_ope_tiers_etat );
 	        g_free ( tmpstr );
 	    }
 	    else
-		text = gsb_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
+		text = utils_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
@@ -825,7 +828,7 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 /* si force = 0, vérifie les dates et affiche si nécessaire */
 /*   si force = 1, affiche le total (chgt de categ, ib ...) */
 /*****************************************************************************************************/
-gint etat_affiche_affiche_total_periode ( gint transaction_number, 
+gint etat_affiche_affiche_total_periode ( gint transaction_number,
 					  gint ligne,
 					  gint force )
 {
@@ -871,7 +874,7 @@ gint etat_affiche_affiche_total_periode ( gint transaction_number,
 
             if ( g_date_get_weekday ( date_debut_periode )  != jour_debut_semaine )
 			{
-                do 
+                do
                 {
                     g_date_subtract_days ( date_debut_periode, 1 );
                 }
@@ -967,7 +970,7 @@ gint etat_affiche_affiche_total_periode ( gint transaction_number,
 
 	    if ( g_date_get_weekday ( date_debut_periode )  != jour_debut_semaine )
 			{
-                do 
+                do
                 {
                     g_date_subtract_days ( date_debut_periode, 1 );
                 }
@@ -1071,7 +1074,7 @@ gint etat_affiche_affiche_total_periode ( gint transaction_number,
 	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	g_free ( text );
 
-	text = gsb_real_get_string_with_currency (montant_periode_etat, devise_generale_etat, TRUE );
+	text = utils_real_get_string_with_currency (montant_periode_etat, devise_generale_etat, TRUE );
 	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	g_free ( text );
 	ligne++;
@@ -1107,7 +1110,7 @@ gint etat_affiche_affiche_total_periode ( gint transaction_number,
 
 		    if ( g_date_get_weekday ( date_debut_periode )  != jour_debut_semaine )
 			{
-                do 
+                do
                 {
                     g_date_subtract_days ( date_debut_periode, 1 );
                 }
@@ -1225,7 +1228,7 @@ gint etat_affiche_affiche_total_exercice ( gint transaction_number,
 	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	g_free ( text );
 
-	text = gsb_real_get_string_with_currency (montant_exo_etat, devise_generale_etat, TRUE );
+	text = utils_real_get_string_with_currency (montant_exo_etat, devise_generale_etat, TRUE );
 	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	g_free ( text );
 	ligne++;
@@ -1503,7 +1506,6 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 	    if ( gsb_data_transaction_get_mother_transaction_number ( transaction_number))
 	    {
 		GSList *list_tmp_transactions;
-		gboolean found = FALSE;
 
 		/* On récupère donc la liste des opérations du compte et on en fait
 		   le tour jusqu'à ce qu'on trouve l'opération mère */
@@ -1525,7 +1527,6 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 			{
 			    gsb_data_transaction_set_method_of_payment_content ( transaction_number,
 										 gsb_data_transaction_get_method_of_payment_content (transaction_number_tmp));
-			    found = TRUE;
 			}
 		    }
 		    list_tmp_transactions = list_tmp_transactions -> next;
@@ -1623,7 +1624,7 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 	/* on affiche le montant au bout de la ligne */
 
-	text = gsb_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
+	text = utils_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
 						  gsb_data_transaction_get_currency_number (transaction_number), TRUE );
 
 	if ( gsb_data_report_get_report_can_click (current_report_number))
@@ -1697,7 +1698,7 @@ gint etat_affiche_affiche_total_partiel ( gsb_real total_partie,
     etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
     g_free ( text );
 
-    text = gsb_real_get_string_with_currency (total_partie, devise_generale_etat, TRUE );
+    text = utils_real_get_string_with_currency (total_partie, devise_generale_etat, TRUE );
     etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
     g_free ( text );
     ligne++;
@@ -1751,7 +1752,7 @@ gint etat_affiche_affiche_total_general ( gsb_real total_general,
     etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
     g_free ( text );
 
-    text = gsb_real_get_string_with_currency (total_general, devise_generale_etat, TRUE );
+    text = utils_real_get_string_with_currency (total_general, devise_generale_etat, TRUE );
     etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
     g_free ( text );
     ligne++;
@@ -1949,7 +1950,7 @@ gint etat_affiche_affiche_sous_categ_etat ( gint transaction_number,
 		    pointeur_char = my_strdup ("");
 	    }
 
-	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
+	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free (pointeur_char);
 	    ligne++;
@@ -2030,7 +2031,7 @@ gint etat_affiche_affiche_ib_etat ( gint transaction_number,
 					      _("No budgetary line"),
 					      NULL );
 
-	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
+	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
@@ -2118,7 +2119,7 @@ gint etat_affiche_affiche_sous_ib_etat ( gint transaction_number,
 		    pointeur_char = g_strdup("");
 	    }
 
-	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
+	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
@@ -2188,7 +2189,7 @@ gint etat_affiche_affiche_compte_etat ( gint transaction_number,
 					  NULL );
 	    nom_compte_en_cours = gsb_data_account_get_name (gsb_data_transaction_get_account_number (transaction_number));
 
-	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
+	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
@@ -2266,7 +2267,7 @@ gint etat_affiche_affiche_tiers_etat ( gint transaction_number,
 					      _("No payee"),
 					      NULL );
 
-	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
+	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
 					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
@@ -2288,15 +2289,15 @@ gint etat_affiche_affiche_tiers_etat ( gint transaction_number,
 /*****************************************************************************************************/
 gint etat_affiche_affiche_titre_revenus_etat ( gint ligne )
 {
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
-    etat_affiche_attach_label ( _("Incomes"), TEXT_LARGE, 0, nb_colonnes-1, 
+    etat_affiche_attach_label ( _("Incomes"), TEXT_LARGE, 0, nb_colonnes-1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
@@ -2308,15 +2309,15 @@ gint etat_affiche_affiche_titre_revenus_etat ( gint ligne )
 /*****************************************************************************************************/
 gint etat_affiche_affiche_titre_depenses_etat ( gint ligne )
 {
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
-    etat_affiche_attach_label ( _("Outgoings"), TEXT_LARGE, 0, nb_colonnes-1, 
+    etat_affiche_attach_label ( _("Outgoings"), TEXT_LARGE, 0, nb_colonnes-1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1,
 				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
@@ -2340,7 +2341,7 @@ gint etat_affiche_affiche_totaux_sous_jaccent ( gint origine,
 
 
     /* on doit partir du bout de la liste pour revenir vers la structure demandée */
-    
+
     pointeur_glist = g_slist_reverse (g_slist_copy ( gsb_data_report_get_sorting_type (current_report_number)));
 
     while ( GPOINTER_TO_INT ( pointeur_glist -> data ) != origine )
@@ -2511,7 +2512,7 @@ void etat_affiche_attach_vsep ( int x, int x2, int y, int y2)
 
 
 
-void etat_affiche_attach_label ( gchar * text, gint properties, int x, int x2, int y, int y2, 
+void etat_affiche_attach_label ( gchar * text, gint properties, int x, int x2, int y, int y2,
 				 enum alignement align, gint transaction_number )
 {
     etat_affichage_output -> attach_label ( text, properties, x, x2, y, y2, align, transaction_number );
