@@ -31,19 +31,21 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_assistant_first.h"
+#include "dialog.h"
 #include "gsb_assistant.h"
 #include "gsb_assistant_file.h"
 #include "gsb_automem.h"
-#include "parametres.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
-#include "traitement_variables.h"
-#include "dialog.h"
-#include "utils_files.h"
-#include "utils.h"
+#include "parametres.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_files.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -57,7 +59,6 @@ static GtkWidget *gsb_assistant_first_page_3 ( GtkWidget *assistant );
 
 /*START_EXTERN*/
 extern gboolean result_reconcile;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 enum first_assistant_page
@@ -137,18 +138,18 @@ GtkResponseType gsb_assistant_first_come_to_0_6 ( void )
     GtkWidget *assistant;
 
     /* create the assistant */
-    assistant = gsb_assistant_new ( _("Welcome to Grisbi 0.6!"),
-				    _("You are using Grisbi 0.6 for the first time.  While most of the " 
+    assistant = gsb_assistant_new ( _("Welcome to Grisbi!"),
+				    _("You are using Grisbi for the first time.  While most of the "
 				      "interface has not changed, you will notice a lot of improvements. "
 				      "Do not hesitate to read some tips of the day to learn more on the new "
-				      "features.\n\n" 
+				      "features.\n\n"
 				      "Of the most notable enhancements to Grisbi, we redesigned the "
 				      "backup function. "
 				      "Grisbi will now automatically put backup files in a directory "
 				      "that you will be able to set manually in next screen.\n\n"
 				      "Also, we advise you to configure your web browser "
 				      "to your system configuration and to configure various settings "
-				      "in next screen.\n\n" 
+				      "in next screen.\n\n"
 				      "If you want to make backups of your Grisbi file in case you want to revert "
 				      "to old version of Grisbi, we would advise you to do that right now.\n\n"
 				      "You can find out other improvements on http://www.grisbi.org/."),
@@ -224,7 +225,7 @@ static GtkWidget *gsb_assistant_first_page_2 ( GtkWidget *assistant )
     entry = gsb_automem_entry_new ( &conf.browser_command, NULL, NULL );
     gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 1, 2, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
 
-    text = make_blue ( _("You may use %s to expand the URL - I.e: 'firefox -remote %s' ") );
+    text = make_blue ( _("You may use %s to expand the URL - I.e: 'firefox %s' ") );
     label = gtk_label_new ( text );
     gtk_label_set_use_markup ( GTK_LABEL(label), TRUE );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
@@ -239,23 +240,31 @@ static GtkWidget *gsb_assistant_first_page_2 ( GtkWidget *assistant )
     /* Automatically load last file on startup? */
     button = gsb_automem_checkbutton_new (_("Automatically load last file on startup"),
 					  &conf.dernier_fichier_auto, NULL, NULL );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), button, 
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
 			 FALSE, FALSE, 0 );
 
     /* automatically save file at closing */
     button = gsb_automem_checkbutton_new (_("Automatically save on exit"),
 					  &conf.sauvegarde_auto, NULL, NULL);
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), button, 
-			 FALSE, FALSE, 0 );
-
-    /* crypt the grisbi file */
-    button = gsb_automem_checkbutton_new ( _("Encrypt Grisbi file"),
-					   &(etat.crypt_file), G_CALLBACK (gsb_gui_encryption_toggled), NULL);
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
 			 FALSE, FALSE, 0 );
 
-    if ( etat.crypt_file )
-        run.new_crypted_file = TRUE;
+    /* crypt the grisbi file */
+#ifdef HAVE_SSL
+    {
+        button = gsb_automem_checkbutton_new ( _("Encrypt Grisbi file"),
+                                               &(etat.crypt_file), G_CALLBACK (gsb_gui_encryption_toggled), NULL);
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
+                             FALSE, FALSE, 0 );
+
+        if ( etat.crypt_file )
+            run.new_crypted_file = TRUE;
+    }
+#else
+    {
+        run.new_crypted_file = FALSE;
+    }
+#endif
 
     /* Automatic backup ? */
     button = gsb_automem_checkbutton_new (_("Make a backup copy before saving files"),
@@ -292,11 +301,11 @@ static GtkWidget *gsb_assistant_first_page_2 ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0);
 
-    dialog = utils_files_create_file_chooser ( window,
+    dialog = utils_files_create_file_chooser ( run.window,
                         _("Select/Create backup directory") );
     button = gtk_file_chooser_button_new_with_dialog (dialog);
     gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (button),
-                        my_get_XDG_grisbi_data_dir () );
+                        gsb_dirs_get_user_data_dir () );
     g_signal_connect ( G_OBJECT (button),
                         "selection-changed",
                         G_CALLBACK (gsb_config_backup_dir_chosen),
@@ -311,7 +320,7 @@ static GtkWidget *gsb_assistant_first_page_2 ( GtkWidget *assistant )
 
 /**
  * create the page 3 of the first assistant
- * this is the page for report error of reconcile import of an old grisbi file
+ * this is the page for report error of reconcile import of an old Grisbi file
  *
  * \param assistant the GtkWidget assistant
  *
@@ -323,15 +332,12 @@ static GtkWidget *gsb_assistant_first_page_3 ( GtkWidget *assistant )
     GtkWidget *vbox;
     GtkWidget *label;
     GtkWidget *paddingbox;
-    GtkSizeGroup *size_group;
     GtkWidget *hbox;
     GtkWidget *image;
 
     page = gtk_hbox_new (FALSE, 15);
     gtk_container_set_border_width ( GTK_CONTAINER (page), 10 );
 
-    size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-
     vbox = new_vbox_with_title_and_icon ( _("Reconciliation"), "reconciliationlg.png" );
     gtk_box_pack_start ( GTK_BOX (page), vbox, TRUE, TRUE, 0 );
 
@@ -359,7 +365,7 @@ static GtkWidget *gsb_assistant_first_page_3 ( GtkWidget *assistant )
 
 
 /**
- * If error creating reconcilaitions, display the third page 
+ * If error creating reconcilaitions, display the third page
  * otherwise exit normally
  *
  * \param assistant
@@ -371,7 +377,7 @@ static gboolean gsb_assistant_first_enter_page_2 ( GtkWidget *assistant,
                         gint new_page )
 {
     if ( result_reconcile == TRUE )
-        gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD, 
+        gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD,
 				       GTK_RESPONSE_APPLY );
 
     return FALSE;
@@ -389,7 +395,7 @@ static gboolean gsb_assistant_first_enter_page_2 ( GtkWidget *assistant,
 static gboolean gsb_assistant_first_enter_page_3 ( GtkWidget *assistant,
                         gint new_page )
 {
-    gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD, 
+    gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD,
 				       GTK_RESPONSE_APPLY );
 
     return FALSE;
