@@ -34,19 +34,17 @@
 #endif
 
 #include "include.h"
+#include <stdlib.h>
+#include <string.h>
+#include <math.h>
+#include <glib/gstdio.h>
 #include <assert.h>
 
 /*START_INCLUDE*/
 #include "gsb_real.h"
 /*END_INCLUDE*/
 
-gsb_real null_real = { 0 , 0 };
-gsb_real error_real = { G_MININT64, 0 };
-
-static gchar *gsb_thousands_sep;
-static gchar *gsb_decimal_point;
-
-glong gsb_real_power_10[] = { 1, 10, 100, 1000, 10000, 100000,
+static glong gsb_real_power_10[] = { 1, 10, 100, 1000, 10000, 100000,
                             1000000, 10000000, 100000000, 1000000000 };
 
 #ifdef _MSC_VER
@@ -66,41 +64,20 @@ static gboolean gsb_real_raw_truncate_number ( gint64 *mantissa, gint *exponent
 /*END_EXTERN*/
 
 
-/**
- * Return the real in a formatted string, according to the currency 
- * regarding decimal separator, thousands separator and positive or
- * negative sign.
- * this is directly the number coded in the real wich is returned
- * usually, gsb_real_get_string_with_currency is better to adapt the format
- * 	of the number to the currency format
- * 
- * \param number	Number to format.
- *
- * \return		A newly allocated string of the number (this
- *			function will never return NULL) 
-*/
-gchar *gsb_real_get_string ( gsb_real number )
-{
-    struct lconv *conv = localeconv ();
-
-    return gsb_real_raw_format_string ( number, conv, FALSE );
-}
-
-
 /**
  * Return the real in a formatted string with an optional currency
  * symbol, according to the given locale regarding decimal separator,
  * thousands separator and positive or negative sign.
- * 
+ *
  * \param number		    Number to format.
- * \param conv      		the locale obtained with localeconv(), or built manually
+ * \param locale      		the locale obtained with localeconv(), or built manually
  * \param currency_symbol 	the currency symbol
  *
  * \return		A newly allocated string of the number (this
- *			function will never return NULL) 
+ *			function will never return NULL)
  */
 gchar *gsb_real_raw_format_string (gsb_real number,
-                        struct lconv *conv,
+                        struct lconv *locale,
                         const gchar *currency_symbol )
 {
     gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
@@ -114,14 +91,14 @@ gchar *gsb_real_raw_format_string (gsb_real number,
     const gchar *cs_end;
     gint nbre_char;
 	lldiv_t units;
-/*printf ("currency_symbol = %s\n", currency_symbol);*/
-    cs_start = (currency_symbol && conv->p_cs_precedes) ? currency_symbol : "";
-    cs_start_space = (currency_symbol && conv->p_cs_precedes && conv->p_sep_by_space) ? " " : "";
-    sign = (number.mantissa < 0) ? conv->negative_sign : conv->positive_sign;
-    mon_decimal_point = gsb_decimal_point;
-    cs_end_space = (currency_symbol && !conv->p_cs_precedes && conv->p_sep_by_space) ? " " : "";
-    cs_end = (currency_symbol && !conv->p_cs_precedes) ? currency_symbol : "";
-    
+
+    cs_start = (currency_symbol && locale->p_cs_precedes) ? currency_symbol : "";
+    cs_start_space = (currency_symbol && locale->p_cs_precedes && locale->p_sep_by_space) ? " " : "";
+    sign = (number.mantissa < 0) ? locale->negative_sign : locale->positive_sign;
+    mon_decimal_point = locale->mon_decimal_point && *locale->mon_decimal_point ? locale->mon_decimal_point : "";
+    cs_end_space = (currency_symbol && !locale->p_cs_precedes && locale->p_sep_by_space) ? " " : "";
+    cs_end = (currency_symbol && !locale->p_cs_precedes) ? currency_symbol : "";
+
     units = lldiv ( llabs (number.mantissa), gsb_real_power_10[number.exponent] );
 
     nbre_char = g_sprintf ( buffer, "%.0f", (gdouble) units.quot );
@@ -130,7 +107,7 @@ gchar *gsb_real_raw_format_string (gsb_real number,
 
     if ( units.quot >= 1000 )
     {
-        temp = gsb_real_add_thousands_sep ( temp, gsb_thousands_sep );
+        temp = gsb_real_add_thousands_sep ( temp, locale->mon_thousands_sep );
     }
 
     g_snprintf ( format, sizeof ( format ), "%s%d%s",
@@ -138,7 +115,7 @@ gchar *gsb_real_raw_format_string (gsb_real number,
                                             number.exponent,
                                             "lld%s%s" );
 
-    result = g_strdup_printf ( format, 
+    result = g_strdup_printf ( format,
                             cs_start,
                             cs_start_space,
                             sign,
@@ -154,29 +131,6 @@ gchar *gsb_real_raw_format_string (gsb_real number,
 }
 
 
-/**
- * get a real number from a string
- * the string can be formatted :
- * - handle , or . as separator
- * - spaces are ignored
- * - another character makes a 0 return
- *
- *   there is no ask for any exponent, so the gsb_real will be exactly the
- *   same as the string
- *
- * \param string
- *
- * \return the number in the string transformed to gsb_real
- * */
-gsb_real gsb_real_get_from_string ( const gchar *string )
-{
-    gsb_real result;
-
-    result =  gsb_real_raw_get_from_string ( string, gsb_thousands_sep, gsb_decimal_point );
-
-    return result;
-}
-
 
 /**
  * get a real number from an integer
@@ -223,8 +177,6 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
     static const gchar *empty_char = "" ;
     const gchar *default_decimal_char_dot = decimal_char_dot;
     const gchar *default_decimal_char_comma = decimal_char_comma;
-    unsigned mts_len;
-    unsigned mdp_len;
     unsigned nb_digits = 0;
     gint64 mantissa = 0;
     gint8 sign = 0;
@@ -235,9 +187,6 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
     if ( !string)
         return error_real;
 
-    mts_len = mon_thousands_sep ? strlen ( mon_thousands_sep ) : 0;
-    mdp_len = mon_decimal_point ? strlen ( mon_decimal_point ) : 0;
-
     if ( mon_thousands_sep )
     {
         if ( g_strstr_len ( mon_thousands_sep, -1, decimal_char_dot ) )
@@ -314,10 +263,10 @@ gsb_real gsb_real_raw_get_from_string ( const gchar *string,
     if (success == TRUE)
     {
         gsb_real result;
+
         result.mantissa = sign * mantissa;
-        result.exponent = ( dot_position >= 0 )
-                          ? nb_digits - dot_position
-                          : 0;
+        result.exponent = ( dot_position >= 0 ) ? nb_digits - dot_position : 0;
+
         return result;
     }
     else
@@ -409,7 +358,7 @@ gsb_real gsb_real_safe_real_from_string ( const gchar *string )
  *
  * \return -1 if number_1 < number_2 ; 0 if number_1 = number_2 ; 1 if number_1 > number_2
  * */
-G_MODULE_EXPORT gint gsb_real_cmp ( gsb_real number_1,
+gint gsb_real_cmp ( gsb_real number_1,
                         gsb_real number_2 )
 {
     gsb_real_normalize ( &number_1,
@@ -589,7 +538,7 @@ gsb_real gsb_real_adjust_exponent ( gsb_real number,
         sign = ( number.mantissa < 0 ) ? -1 : 1;
 
         tmp_num = lldiv ( llabs ( number.mantissa ), gsb_real_power_10[exponent] );
-        
+
         if ( tmp_num.rem > ( 0.5 * gsb_real_power_10[exponent] ) )
             number.mantissa = ( tmp_num.quot + 1 ) * sign;
         else
@@ -615,7 +564,7 @@ gsb_real gsb_real_adjust_exponent ( gsb_real number,
  *
  * \return a gsb_real = number_1 + number_2, or error_real when an error occured
  * */
-G_MODULE_EXPORT gsb_real gsb_real_add ( gsb_real number_1,
+gsb_real gsb_real_add ( gsb_real number_1,
                         gsb_real number_2 )
 {
     gint64 mantissa;
@@ -660,7 +609,7 @@ gsb_real gsb_real_sub ( gsb_real number_1,
  *
  * \return its opposite
  * */
-G_MODULE_EXPORT gsb_real gsb_real_opposite ( gsb_real number )
+gsb_real gsb_real_opposite ( gsb_real number )
 {
     number.mantissa = -number.mantissa;
     return number;
@@ -715,12 +664,12 @@ gsb_real gsb_real_div ( gsb_real number_1,
 {
     gsb_real number;
 	gint64 reste;
-	
+
 	if ( number_1.mantissa == error_real.mantissa ||
 	     number_2.mantissa == error_real.mantissa ||
 	     !number_2.mantissa )
 		return error_real;
-	
+
 	reste = number_1.mantissa % number_2.mantissa;
 
 	if( ( number_1.mantissa >= number_2.mantissa ) && !reste )
@@ -750,7 +699,7 @@ gsb_real gsb_real_div ( gsb_real number_1,
  *
  * \return the number in gsb_real format
  * */
-G_MODULE_EXPORT gsb_real gsb_real_double_to_real ( gdouble number )
+gsb_real gsb_real_double_to_real ( gdouble number )
 {
 	return gsb_real_double_to_real_add_exponent(number, 0);
 }
@@ -854,6 +803,7 @@ gchar *gsb_real_safe_real_to_string ( gsb_real number, gint default_exponent )
     gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
     gchar format[40];
     gchar *result = NULL;
+    gchar *partie_entiere;
     const gchar *sign;
     const gchar *mon_decimal_point;
     gint nbre_char;
@@ -877,18 +827,19 @@ gchar *gsb_real_safe_real_to_string ( gsb_real number, gint default_exponent )
 
     nbre_char = g_sprintf ( buffer, "%.0f", (gdouble) units.quot );
 
-    result = g_strndup ( buffer, nbre_char );
+    partie_entiere = g_strndup ( buffer, nbre_char );
 
     g_snprintf ( format, sizeof ( format ), "%s%d%s",
                                             "%s%s%s%0",
                                             number.exponent,
                                             "lld" );
 
-    result = g_strdup_printf ( format, 
+    result = g_strdup_printf ( format,
                             sign,
-                            result,
+                            partie_entiere,
                             mon_decimal_point,
                             units.rem );
+    g_free( partie_entiere );
 
 /*     printf ("number.mantissa = %lld number.exponent = %d résultat = %s\n",
  *                         number.mantissa, number.exponent, result );
@@ -978,6 +929,7 @@ gchar *gsb_real_add_thousands_sep ( gchar *str_number, const gchar *thousands_se
         g_strfreev ( tab_str );
     }
 
+    g_free ( mon_thousands_sep );
     g_free ( str_number );
     g_free ( dest );
 
@@ -985,67 +937,6 @@ gchar *gsb_real_add_thousands_sep ( gchar *str_number, const gchar *thousands_se
 }
 
 
-/**
- *
- * The returned string should be freed with g_free() when no longer needed.
- *
- *
- * */
-gchar *gsb_real_get_decimal_point ( void )
-{
-    return g_strdup ( gsb_decimal_point );
-}
-
-
-/**
- *
- *
- *
- *
- * */
-void gsb_real_set_decimal_point ( const gchar *decimal_point )
-{
-    if ( gsb_decimal_point && strlen ( gsb_decimal_point ) )
-        g_free ( gsb_decimal_point );
-
-    if ( decimal_point == NULL )
-        gsb_decimal_point = NULL;
-    else
-		gsb_decimal_point = g_strdup ( decimal_point );
-}
-
-
-/**
- *
- * The returned string should be freed with g_free() when no longer needed.
- *
- *
- * */
-gchar *gsb_real_get_thousands_sep ( void )
-{
-    return g_strdup ( gsb_thousands_sep );
-}
-
-
-/**
- *
- *
- *
- *
- * */
-void gsb_real_set_thousands_sep ( const gchar *thousands_sep )
-{
-    if ( gsb_thousands_sep && strlen ( gsb_thousands_sep ) )
-        g_free ( gsb_thousands_sep );
-
-    if ( thousands_sep == NULL )
-        gsb_thousands_sep = NULL;
-    else
-        gsb_thousands_sep = g_strdup ( thousands_sep );
-}
-
-
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
-
