@@ -27,6 +27,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 #define START_INCLUDE
 #include "tip.h"
@@ -38,7 +39,7 @@
 static const gchar* tips[] =
 {
     N_("You can reconcile transactions to match your real financial state as "
-    "seen on your bank receipts.  If you just spend 15mn each month reconciling "
+    "seen on your bank receipts. If you just spend 15mn each month reconciling "
     "Grisbi transactions with your bank receipts, you are guaranteed that your "
     "accounts are in perfect shape."),
     N_("Grisbi automatically saves a copy of your work if it crashes.\n\nThus "
@@ -57,8 +58,8 @@ static const gchar* tips[] =
     N_("You can encrypt your Grisbi files to improve your privacy.  Just select "
     "the 'Encrypt Grisbi file' in preferences window and enter a password next "
     "time you save your file.\n\nEncryption is irreversible, if you loose your "
-    "password, there is NO WAY to restore your Grisbi accounts.  Use with "
-    "caution !"),
+    "password, there is NO WAY to restore your Grisbi accounts. Use with "
+    "caution!"),
     N_("You can efficiently manage your professional expenses with Grisbi.\n\n"
     "Create a <i>Professional expenses</i> budgetary line and put all "
     "professional expenses there.  When you are paid, split your salary as a "
@@ -90,19 +91,19 @@ static const gchar* tips[] =
     "possibily put old transactions into separate files for archival.  Use "
     "'File/Archive transaction' menu to achieve this."),
     N_("If unused payees have accumulated in the course of time due to bank "
-    "imports, you can remove all of them in one click!  Just go to the "
+    "imports, you can remove all of them in one click! Just go to the "
     "<i>Payees</i> page and click on the 'Remove unused payees' button."),
     N_("You can sort the transaction list according to any criteria.  Click on "
-    "the column titles to sort transactions differently.  For example, you can "
+    "the column titles to sort transactions differently. For example, you can "
     "sort transactions by payee or category name."),
     N_("You can reorder accounts in the navigation list using drag &amp; drop."),
     N_("You can have future scheduled transactions 'executed' before their date, "),
-    N_("No more tip available !  Please send any tips you know to "
+    N_("No more tip available!  Please send any tips you know to "
     "grisbi-devel@lists.sourceforge.net so that we can include them in next "
     "version for all users.")
 };
 
-/** 
+/**
  * Display a tip forcefully, even if show_tip option has been disabled.
  */
 void force_display_tip (  )
@@ -125,45 +126,45 @@ void display_tip ( gboolean force )
     GtkWidget *btn_back, *btn_forward, *btn_close;
     gchar *tmpstr;
 
-    if ( !force && !etat.show_tip )
+    if ( !force && !conf.show_tip )
         return;
 
-    etat.last_tip = CLAMP (etat.last_tip+1, 0, sizeof(tips)/sizeof(gpointer)-1);
+    conf.last_tip = CLAMP ( conf.last_tip+1, 0, sizeof(tips)/sizeof(gpointer)-1);
 
     dialog = dialogue_special_no_run ( GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
                         make_hint ( _("Did you know that..."),
-                        /* We use the grisbi-tips catalog */
-                        g_dgettext(NULL, tips[etat.last_tip]) ) );
+                        /* We use the Grisbi-tips catalog */
+                        g_dgettext(NULL, tips[conf.last_tip]) ) );
     gtk_window_set_modal ( GTK_WINDOW ( dialog ), FALSE );
 
-    checkbox = gsb_automem_checkbutton_new ( _("Display tips at next start"), 
-                        &(etat.show_tip), NULL, NULL );
+    checkbox = gsb_automem_checkbutton_new ( _("Display tips at next start"),
+                        &(conf.show_tip), NULL, NULL );
     gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG(dialog) -> vbox ), checkbox, FALSE, FALSE, 6 );
     gtk_widget_show ( checkbox );
 
     btn_back =    gtk_dialog_add_button (GTK_DIALOG(dialog), GTK_STOCK_GO_BACK, 1);
     btn_forward = gtk_dialog_add_button (GTK_DIALOG(dialog), GTK_STOCK_GO_FORWARD, 2);
     btn_close =   gtk_dialog_add_button (GTK_DIALOG(dialog), GTK_STOCK_CLOSE, 3);
- 
+
     /* gtk_widget_set_size_request ( dialog, 450, -1 ); */
     /* We iterate as user can select several tips. */
     while ( TRUE )
     {
-    if (etat.last_tip == sizeof(tips)/sizeof(gpointer)-1)
+    if ( conf.last_tip == sizeof(tips)/sizeof(gpointer)-1)
         gtk_widget_set_sensitive (btn_forward, FALSE);
-    if (etat.last_tip == 0)
+    if ( conf.last_tip == 0)
         gtk_widget_set_sensitive (btn_back, FALSE);
 
     switch ( gtk_dialog_run ( GTK_DIALOG(dialog) ) )
     {
         case 1:
-        if ( etat.last_tip > 0 )
-            etat.last_tip--;
-        gtk_widget_set_sensitive (btn_forward, TRUE); 
+        if ( conf.last_tip > 0 )
+            conf.last_tip--;
+        gtk_widget_set_sensitive (btn_forward, TRUE);
         tmpstr = g_strconcat ( make_pango_attribut (
                         "size=\"larger\" weight=\"bold\"", _("Did you know that...") ),
                         "\n\n",
-                        g_dgettext (NULL, tips[etat.last_tip] ),
+                        g_dgettext (NULL, tips[conf.last_tip] ),
                         NULL );
 
         gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog) -> label ),
@@ -172,12 +173,12 @@ void display_tip ( gboolean force )
         break;
 
         case 2:
-        if (etat.last_tip < sizeof(tips)/sizeof(gpointer)-1)
-            etat.last_tip++;
+        if ( conf.last_tip < sizeof(tips)/sizeof(gpointer)-1)
+            conf.last_tip++;
         tmpstr = g_strconcat ( make_pango_attribut (
                         "size=\"larger\" weight=\"bold\"", _("Did you know that...") ),
                         "\n\n",
-                        g_dgettext (NULL, tips[etat.last_tip] ),
+                        g_dgettext (NULL, tips[conf.last_tip] ),
                         NULL );
 
         gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog) -> label ),
